summaryrefslogtreecommitdiffstats
path: root/src/Exceptions/ParserException.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/Exceptions/ParserException.php')
-rw-r--r--src/Exceptions/ParserException.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/Exceptions/ParserException.php b/src/Exceptions/ParserException.php
index e23d03d..7332674 100644
--- a/src/Exceptions/ParserException.php
+++ b/src/Exceptions/ParserException.php
@@ -20,13 +20,13 @@ class ParserException extends \Exception
/**
* Constructor.
*
* @param string $message
* @param Token $token
* @param int $code
*/
- public function __construct($message = '', Token $token = null, $code = 0)
+ public function __construct($msg = '', Token $token = null, $code = 0)
{
- parent::__construct($message, $code);
+ parent::__construct($msg, $code);
$this->token = $token;
}
}
@@ -20,13 +20,13 @@ class ParserException extends \Exception
* Constructor.
*
- * @param string $message
- * @param Token $token
- * @param int $code
+ * @param string $msg The message of this exception.
+ * @param Token $token The token that produced this exception.
+ * @param int $code The code of this error.
*/